@@ -1,6 +1,6 @@
 
 /*
- * $Id: client_side.c,v 1.90 1997/02/24 20:21:37 wessels Exp $
+ * $Id: client_side.c,v 1.90.2.1 1997/02/27 17:49:41 wessels Exp $
  *
  * DEBUG: section 33    Client-side Routines
  * AUTHOR: Duane Wessels
@@ -99,13 +99,17 @@ clientProxyAuthCheck(icpStateData * icpState)
     /* Check that the user is allowed to access via this proxy-cache
      * don't restrict if they're accessing a local domain or
      * an object of type cacheobj:// */
-    if (Config.proxyAuthFile == NULL)
+    if (Config.proxyAuth.File == NULL)
 	return 1;
     if (urlParseProtocol(icpState->url) == PROTO_CACHEOBJ)
 	return 1;
-    if (Config.proxyAuthIgnoreDomain != NULL)
-	if (matchDomainName(Config.proxyAuthIgnoreDomain, icpState->request->host))
+
+    if (Config.proxyAuth.IgnoreDomains) {
+	if (aclMatchRegex(Config.proxyAuth.IgnoreDomains, icpState->request->host)) {
+	    debug(33, 2, "clientProxyAuthCheck: host \"%s\" matched proxyAuthIgnoreDomains\n", icpState->request->host);
 	    return 1;
+	}
+    }
     proxy_user = proxyAuthenticate(icpState->request_hdr);
     xstrncpy(icpState->ident.ident, proxy_user, ICP_IDENT_SZ);
     debug(33, 6, "clientProxyAuthCheck: user = %s\n", icpState->ident.ident);
@@ -328,11 +332,11 @@ proxyAuthenticate(const char *headers)
      */
 
     if ((squid_curtime - last_time) > CHECK_PROXY_FILE_TIME) {
-	debug(33, 5, "proxyAuthenticate: checking password file %s hasn't changed\n", Config.proxyAuthFile);
+	debug(33, 5, "proxyAuthenticate: checking password file %s hasn't changed\n", Config.proxyAuth.File);
 
-	if (stat(Config.proxyAuthFile, &buf) == 0) {
+	if (stat(Config.proxyAuth.File, &buf) == 0) {
 	    if (buf.st_mtime != change_time) {
-		debug(33, 0, "proxyAuthenticate: reloading changed proxy authentication password file %s \n", Config.proxyAuthFile);
+		debug(33, 0, "proxyAuthenticate: reloading changed proxy authentication password file %s \n", Config.proxyAuth.File);
 		change_time = buf.st_mtime;
 
 		if (validated != 0) {
@@ -345,14 +349,14 @@ proxyAuthenticate(const char *headers)
 		    /* First time around, 7921 should be big enough */
 		    if ((validated = hash_create(urlcmp, 7921, hash_string)) < 0) {
 			debug(33, 1, "ERK: can't create hash table. Turning auth off");
-			xfree(Config.proxyAuthFile);
-			Config.proxyAuthFile = NULL;
+			xfree(Config.proxyAuth.File);
+			Config.proxyAuth.File = NULL;
 			return (dash_str);
 		    }
 		}
 
 		passwords = xmalloc((size_t) buf.st_size + 2);
-		f = fopen(Config.proxyAuthFile, "r");
+		f = fopen(Config.proxyAuth.File, "r");
 		fread(passwords, (size_t) buf.st_size, 1, f);
 		*(passwords + buf.st_size) = '\0';
 		strcat(passwords, "\n");
@@ -374,9 +378,9 @@ proxyAuthenticate(const char *headers)
 		xfree(passwords);
 	    }
 	} else {
-	    debug(33, 1, "ERK: can't access proxy_auth file %s. Turning authentication off", Config.proxyAuthFile);
-	    xfree(Config.proxyAuthFile);
-	    Config.proxyAuthFile = NULL;
+	    debug(33, 1, "ERK: can't access proxy_auth file %s. Turning authentication off", Config.proxyAuth.File);
+	    xfree(Config.proxyAuth.File);
+	    Config.proxyAuth.File = NULL;
 	    return (dash_str);
 	}
     }
