@@ -1,6 +1,6 @@
 
 /*
- * $Id: pass.c,v 1.29 1997/02/24 18:00:21 wessels Exp $
+ * $Id: pass.c,v 1.29.2.3 1997/03/03 17:09:25 wessels Exp $
  *
  * DEBUG: section 39    HTTP Passthrough
  * AUTHOR: Duane Wessels
@@ -48,7 +48,6 @@ typedef struct {
     time_t timeout;
     int *size_ptr;		/* pointer to size for logging */
     int proxying;
-    ConnectStateData connectState;
 } PassStateData;
 
 static void passLifetimeExpire _PARAMS((int fd, void *));
@@ -118,7 +117,6 @@ passStateFree(int fd, void *data)
     xfree(passState->url);
     requestUnlink(passState->request);
     requestUnlink(passState->proxy_request);
-    memset(passState, '\0', sizeof(PassStateData));
     safe_free(passState);
 }
 
@@ -310,7 +308,7 @@ passConnected(int fd, void *data)
 	opt_forwarded_for ? passState->client.fd : -1);
     debug(39, 3, "passConnected: Appending %d bytes of content\n",
 	passState->buflen - hdr_len);
-    memcpy(passState->client.buf + passState->client.len,
+    xmemcpy(passState->client.buf + passState->client.len,
 	passState->buf + hdr_len,
 	passState->buflen - hdr_len);
     passState->client.len += passState->buflen - hdr_len;
@@ -376,12 +374,11 @@ passConnect(int fd, const ipcache_addrs * ia, void *data)
 	COMM_SELECT_LIFETIME,
 	passLifetimeExpire,
 	(void *) passState, 0);
-    passState->connectState.fd = fd;
-    passState->connectState.host = passState->host;
-    passState->connectState.port = passState->port;
-    passState->connectState.handler = passConnectDone;
-    passState->connectState.data = passState;
-    comm_nbconnect(fd, &passState->connectState);
+    commConnectStart(fd,
+	passState->host,
+	passState->port,
+	passConnectDone,
+	passState);
 }
 
 static void
@@ -408,8 +405,6 @@ passConnectDone(int fd, int status, void *data)
     if (opt_no_ipcache)
 	ipcacheInvalidate(passState->host);
     passConnected(passState->server.fd, passState);
-    if (vizSock > -1)
-	vizHackSendPkt(&passState->connectState.S, 2);
 }
 
 int
