@@ -1,6 +1,6 @@
 
 /*
- * $Id: squid.h,v 1.95.2.10 1997/03/03 17:09:28 wessels Exp $
+ * $Id: squid.h,v 1.95.2.13 1997/03/27 22:19:15 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -270,8 +270,8 @@ typedef int (*QS) (const void *, const void *);
 #include "cache_cf.h"
 #include "comm.h"
 #include "debug.h"
-#include "disk.h"
 #include "fdstat.h"
+#include "disk.h"
 #include "filemap.h"
 #include "hash.h"
 #include "proto.h"		/* must go before neighbors.h */
@@ -303,6 +303,7 @@ typedef int (*QS) (const void *, const void *);
 #include "client_db.h"
 #include "objcache.h"
 #include "refresh.h"
+#include "unlinkd.h"
 
 #if !HAVE_TEMPNAM
 #include "tempnam.h"
@@ -330,6 +331,7 @@ extern int opt_catch_signals;	/* main.c */
 extern int opt_no_ipcache;	/* main.c */
 extern int vhost_mode;		/* main.c */
 extern int Squid_MaxFD;		/* main.c */
+extern int Biggest_FD;		/* main.c */
 extern const char *const version_string;	/* main.c */
 extern const char *const appname;	/* main.c */
 extern struct in_addr local_addr;	/* main.c */
@@ -343,12 +345,11 @@ extern int opt_forwarded_for;	/* main.c */
 extern int opt_accel_uses_host;	/* main.c */
 extern char ThisCache[];	/* main.c */
 
-/* Prototypes and definitions which don't really deserve a seaprate
+/* Prototypes and definitions which don't really deserve a separate
  * include file */
 
 #define  CONNECT_PORT        443
 
-extern int objcacheStart _PARAMS((int, const char *, StoreEntry *));
 extern void start_announce _PARAMS((void *unused));
 extern int sslStart _PARAMS((int fd, const char *, request_t *, char *, int *sz));
 extern const char *storeToString _PARAMS((const StoreEntry *));
